@@ -4,7 +4,7 @@ use warnings FATAL => 'all';
 package HTML::Tested::Test::Upload;
 use base 'HTML::Tested::Test::Value';
 
-sub _convert_to_param {
+sub convert_to_param {
 	my ($class, $obj_class, $r, $name, $val) = @_;
 	$r->add_upload($name, $val);
 }
